%define ALD_Ver		2.0

Name:         libsndfile

License:      LGPL
Summary:      A library to handle various audio file formats
Version:      1.2.2
Release:      0
URL:          https://www.xiph.org/

#https://github.com/libsndfile/libsndfile/releases/

Requires:	libogg >= 1.3.0
Requires:	libvorbis >= 1.2.3
Requires:	flac >= 1.3.1
Requires:	opus >= 1.1
Requires:	lame >= 3.100
Requires:	mpg123 >= 1.25.10

Source: %{name}-%{version}.tar.xz

%define DestDir		/Multimedia
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
libsndfile is a C library for reading and writing sound files such as
AIFF, AU and WAV files through one standard interface. It can currently
read/write 8, 16, 24 and 32-bit PCM files as well as 32-bit floating
point WAV files and a number of compressed formats.
#-------------------------------
%package tools
Summary:      sndfile tools
%description tools
sndfile tools
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Requires:     %{name} = %{version}
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package doc
Summary:      doc html for %{name}
%description doc
doc html for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
#sed -i s:"-O3 ":: configure

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -O2 -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"

CFLAGS="$OPTFLAGS -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="-Wl,--gc-sections"
export INSTALL="/usr/bin/install -p -c"
export PYTHON=/usr/bin/python3

%configure \
	--enable-shared \
	--disable-static \
	--disable-libtool-lock \
	--disable-silent-rules \
	--disable-sqlite \
	--enable-alsa \
	--disable-octave \
	&>FConfigure_log.txt

# Remove useless /usr/lib64 rpath on 64bit archs
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>Finstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la

cp -a AUTHORS README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/lgpl-2.1.txt $RPM_BUILD_ROOT%{docdir}/COPYING

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

%{_rpmconfigdir}/check-rpaths

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_bindir}/sndfile-convert
%{_bindir}/sndfile-info
%{_bindir}/sndfile-play
%{_libdir}/*.so.*
%{_mandir}/man1/sndfile-convert.1.gz
%{_mandir}/man1/sndfile-info.1.gz
%{_mandir}/man1/sndfile-play.1.gz
%dir %{docdir}/
%{docdir}/AUTHORS
%{docdir}/COPYING
%{docdir}/README

%files tools
%{_bindir}/sndfile-cmp
%{_bindir}/sndfile-concat
%{_bindir}/sndfile-deinterleave
%{_bindir}/sndfile-interleave
%{_bindir}/sndfile-metadata-get
%{_bindir}/sndfile-metadata-set
#{_bindir}/sndfile-regtest
%{_bindir}/sndfile-salvage
%{_mandir}/man1/sndfile-cmp.1.gz
%{_mandir}/man1/sndfile-concat.1.gz
%{_mandir}/man1/sndfile-deinterleave.1.gz
%{_mandir}/man1/sndfile-interleave.1.gz
%{_mandir}/man1/sndfile-metadata-get.1.gz
%{_mandir}/man1/sndfile-metadata-set.1.gz
%{_mandir}/man1/sndfile-salvage.1.gz

%files devel
%{_includedir}
%{_libdir}/pkgconfig
%{_libdir}/*.so

%files doc
%{docdir}/*.css
%{docdir}/*.md
%{docdir}/*.jpg
